import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_android_app/domain/models/card.dart';
import 'package:flutter_android_app/presentation/details_page/details_page.dart';

part 'card.dart';

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key, required this.title});

  final String title;

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

class _MyHomePageState extends State<MyHomePage> {
  @override
  void initState() {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text('Hello', style: Theme.of(context).textTheme.bodyLarge),
        backgroundColor: Colors.deepPurple.shade200,
        duration: const Duration(seconds: 4),
      ));
    });
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        backgroundColor: Colors.deepPurple.shade200,
        title: Text(widget.title),
      ),
      body: const Body(),
    );
  }
}

class Body extends StatelessWidget {
  const Body({super.key});

  @override
  Widget build(BuildContext context) {
    final cardsData = [
      CardData(
        title: 'Title 1',
        description: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit',
        imageUrl: 'https://i.imgur.com/a9WA68S.png',
      ),
      CardData(
        title: 'Title 2',
        description: 'Lorem ipsum dolor sit amet',
        icon: Icons.add_chart_outlined,
        imageUrl: 'https://i.imgur.com/dAUcs6I.png',
      ),
      CardData(
        title: 'Title 3',
        description: 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor',
        imageUrl: 'https://i.imgur.com/m2FhVAK.png',
      ),
    ];

    return Center(
      child: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: cardsData.map((data) {
            return _Card.fromData(
                data,
                onLike: (String title, bool isLiked) => _showSnackBar(context, title, isLiked),
                onTap: () => _navToDetails(context, data),
            );
          }).toList(),
        ),
      ),
    );
  }

  void _showSnackBar(BuildContext context, String title, bool isLiked) {
    WidgetsBinding.instance.addPostFrameCallback((_) {
      ScaffoldMessenger.of(context).showSnackBar(SnackBar(
        content: Text(
          'Card $title ${isLiked ? 'liked' : 'disliked'}',
          style: Theme.of(context).textTheme.bodyLarge
        ),
        backgroundColor: Colors.deepPurple.shade200,
        duration: const Duration(seconds: 2),
      ));
    });
  }

  void _navToDetails(BuildContext context, CardData data) {
    Navigator.push(context, CupertinoPageRoute(builder: (context) => DetailsPage(data)));
  }
}
